==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/Credentials.c <==
// public class gnu.java.net.protocol.http.Credentials

// class file dependencies
// @dep_class 4e57e7668ee9620c gnu_java_net_protocol_http_Credentials
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String

// header file dependencies
// @dep_header gnu_java_net_protocol_http_Credentials
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "gnu/java/net/protocol/http/Credentials.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.String username
static _jc_field _jc_gnu_java_net_protocol_http_Credentials$field_info$username = {
	.name=		"username",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_gnu_java_net_protocol_http_Credentials$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_gnu_java_net_protocol_http_Credentials$object, refs[-1].gnu_java_net_protocol_http_Credentials.username),
};

// private java.lang.String password
static _jc_field _jc_gnu_java_net_protocol_http_Credentials$field_info$password = {
	.name=		"password",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_gnu_java_net_protocol_http_Credentials$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_gnu_java_net_protocol_http_Credentials$object, refs[-1].gnu_java_net_protocol_http_Credentials.password),
};

// Fields
static _jc_field *const _jc_gnu_java_net_protocol_http_Credentials$fields[] = {
	&_jc_gnu_java_net_protocol_http_Credentials$field_info$password,
	&_jc_gnu_java_net_protocol_http_Credentials$field_info$username
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, java.lang.String)
//

static _jc_linenum _jc_gnu_java_net_protocol_http_Credentials$linenum_table$_init$a34354cd9552963f[];

static const unsigned char _jc_gnu_java_net_protocol_http_Credentials$param_ptypes$_init$a34354cd9552963f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_gnu_java_net_protocol_http_Credentials$param_types$_init$a34354cd9552963f[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$_init$a34354cd9552963f = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_gnu_java_net_protocol_http_Credentials$type,
	.param_types=		&_jc_gnu_java_net_protocol_http_Credentials$param_types$_init$a34354cd9552963f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_java_net_protocol_http_Credentials$param_ptypes$_init$a34354cd9552963f,
	.signature_hash=	_JC_JLONG(0xa34354cd9552963f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_protocol_http_Credentials$method$_init$a34354cd9552963f,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_gnu_java_net_protocol_http_Credentials$linenum_table$_init$a34354cd9552963f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_protocol_http_Credentials, _init$a34354cd9552963f);

void
_jc_gnu_java_net_protocol_http_Credentials$method$_init$a34354cd9552963f(_jc_env *const env, _jc_gnu_java_net_protocol_http_Credentials$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_gnu_java_net_protocol_http_Credentials$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(67);				// 0
	_JC_REF_FIELD(env, r0, gnu_java_net_protocol_http_Credentials, username) = r1;
	_JC_LINE_NUMBER(68);				// 1
	_JC_REF_FIELD(env, r0, gnu_java_net_protocol_http_Credentials, password) = r2;
	_JC_LINE_NUMBER(69);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getPassword()
//

static _jc_linenum _jc_gnu_java_net_protocol_http_Credentials$linenum_table$getPassword$32d96361835935c6[];

static const unsigned char _jc_gnu_java_net_protocol_http_Credentials$param_ptypes$getPassword$32d96361835935c6[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$getPassword$32d96361835935c6 = {
	.name=			"getPassword",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_gnu_java_net_protocol_http_Credentials$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_gnu_java_net_protocol_http_Credentials$param_ptypes$getPassword$32d96361835935c6,
	.signature_hash=	_JC_JLONG(0x32d96361835935c6),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_protocol_http_Credentials$method$getPassword$32d96361835935c6,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_net_protocol_http_Credentials$vtable, gnu_java_net_protocol_http_Credentials.getPassword$32d96361835935c6) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_net_protocol_http_Credentials$linenum_table$getPassword$32d96361835935c6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_protocol_http_Credentials, getPassword$32d96361835935c6);

_jc_java_lang_String$object *
_jc_gnu_java_net_protocol_http_Credentials$method$getPassword$32d96361835935c6(_jc_env *const env, _jc_gnu_java_net_protocol_http_Credentials$object *this)
{
	struct _jc_gnu_java_net_protocol_http_Credentials$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(84);				// 0
	r1 = _JC_REF_FIELD(env, r0, gnu_java_net_protocol_http_Credentials, password);
	return r1;
}

//
// public java.lang.String getUsername()
//

static _jc_linenum _jc_gnu_java_net_protocol_http_Credentials$linenum_table$getUsername$3aabb4fed0b6ee73[];

static const unsigned char _jc_gnu_java_net_protocol_http_Credentials$param_ptypes$getUsername$3aabb4fed0b6ee73[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$getUsername$3aabb4fed0b6ee73 = {
	.name=			"getUsername",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_gnu_java_net_protocol_http_Credentials$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_gnu_java_net_protocol_http_Credentials$param_ptypes$getUsername$3aabb4fed0b6ee73,
	.signature_hash=	_JC_JLONG(0x3aabb4fed0b6ee73),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_protocol_http_Credentials$method$getUsername$3aabb4fed0b6ee73,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_net_protocol_http_Credentials$vtable, gnu_java_net_protocol_http_Credentials.getUsername$3aabb4fed0b6ee73) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_net_protocol_http_Credentials$linenum_table$getUsername$3aabb4fed0b6ee73
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_protocol_http_Credentials, getUsername$3aabb4fed0b6ee73);

_jc_java_lang_String$object *
_jc_gnu_java_net_protocol_http_Credentials$method$getUsername$3aabb4fed0b6ee73(_jc_env *const env, _jc_gnu_java_net_protocol_http_Credentials$object *this)
{
	struct _jc_gnu_java_net_protocol_http_Credentials$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(76);				// 0
	r1 = _JC_REF_FIELD(env, r0, gnu_java_net_protocol_http_Credentials, username);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_java_net_protocol_http_Credentials$methods[] = {
	&_jc_gnu_java_net_protocol_http_Credentials$method_info$_init$a34354cd9552963f,
	&_jc_gnu_java_net_protocol_http_Credentials$method_info$getPassword$32d96361835935c6,
	&_jc_gnu_java_net_protocol_http_Credentials$method_info$getUsername$3aabb4fed0b6ee73
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_bucket_12[] = {
	&_jc_gnu_java_net_protocol_http_Credentials$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[12]=	_jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_bucket_12,
	[113]=	_jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_java_net_protocol_http_Credentials$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_java_net_protocol_http_Credentials$vtype _jc_gnu_java_net_protocol_http_Credentials$type = {
    .type= {
	.name=			"gnu/java/net/protocol/http/Credentials",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x4e57e7668ee9620c),
		.source_file=		"Credentials.java",
		.instance_size=		sizeof(_jc_gnu_java_net_protocol_http_Credentials$refs) + sizeof(_jc_gnu_java_net_protocol_http_Credentials$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_gnu_java_net_protocol_http_Credentials$fields) / sizeof(*_jc_gnu_java_net_protocol_http_Credentials$fields),
		.fields=		_jc_gnu_java_net_protocol_http_Credentials$fields,
		.num_methods=		sizeof(_jc_gnu_java_net_protocol_http_Credentials$methods) / sizeof(*_jc_gnu_java_net_protocol_http_Credentials$methods),
		.methods=		_jc_gnu_java_net_protocol_http_Credentials$methods,
		.instanceof_hash_table=	_jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_java_net_protocol_http_Credentials$class_depends) / sizeof(*_jc_gnu_java_net_protocol_http_Credentials$class_depends),
		.class_depends=		_jc_gnu_java_net_protocol_http_Credentials$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_java_net_protocol_http_Credentials= {
	    .getPassword$32d96361835935c6=
		&_jc_gnu_java_net_protocol_http_Credentials$method$getPassword$32d96361835935c6,
	    .getUsername$3aabb4fed0b6ee73=
		&_jc_gnu_java_net_protocol_http_Credentials$method$getUsername$3aabb4fed0b6ee73,
	},
    }
};

==> jc-1.4.5.tar.gz: gnu/java/net/protocol/http/Credentials.c <==
// public class gnu.java.net.protocol.http.Credentials

// class file dependencies
// @dep_class 4e57e7668ee9620c gnu_java_net_protocol_http_Credentials
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String

// header file dependencies
// @dep_header gnu_java_net_protocol_http_Credentials
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "gnu/java/net/protocol/http/Credentials.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.String username
static _jc_field _jc_gnu_java_net_protocol_http_Credentials$field_info$username = {
	.name=		"username",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_gnu_java_net_protocol_http_Credentials$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_gnu_java_net_protocol_http_Credentials$object, refs[-1].gnu_java_net_protocol_http_Credentials.username),
};

// private java.lang.String password
static _jc_field _jc_gnu_java_net_protocol_http_Credentials$field_info$password = {
	.name=		"password",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_gnu_java_net_protocol_http_Credentials$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_gnu_java_net_protocol_http_Credentials$object, refs[-1].gnu_java_net_protocol_http_Credentials.password),
};

// Fields
static _jc_field *const _jc_gnu_java_net_protocol_http_Credentials$fields[] = {
	&_jc_gnu_java_net_protocol_http_Credentials$field_info$password,
	&_jc_gnu_java_net_protocol_http_Credentials$field_info$username
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, java.lang.String)
//

static _jc_linenum _jc_gnu_java_net_protocol_http_Credentials$linenum_table$_init$a34354cd9552963f[];

static const unsigned char _jc_gnu_java_net_protocol_http_Credentials$param_ptypes$_init$a34354cd9552963f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_gnu_java_net_protocol_http_Credentials$param_types$_init$a34354cd9552963f[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$_init$a34354cd9552963f = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_gnu_java_net_protocol_http_Credentials$type,
	.param_types=		&_jc_gnu_java_net_protocol_http_Credentials$param_types$_init$a34354cd9552963f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_java_net_protocol_http_Credentials$param_ptypes$_init$a34354cd9552963f,
	.signature_hash=	_JC_JLONG(0xa34354cd9552963f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_protocol_http_Credentials$method$_init$a34354cd9552963f,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_gnu_java_net_protocol_http_Credentials$linenum_table$_init$a34354cd9552963f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_protocol_http_Credentials, _init$a34354cd9552963f);

void _JC_JCNI_ATTR
_jc_gnu_java_net_protocol_http_Credentials$method$_init$a34354cd9552963f(_jc_env *const env, _jc_gnu_java_net_protocol_http_Credentials$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_gnu_java_net_protocol_http_Credentials$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(67);				// 0
	_JC_REF_FIELD(env, r0, gnu_java_net_protocol_http_Credentials, username) = r1;
	_JC_LINE_NUMBER(68);				// 1
	_JC_REF_FIELD(env, r0, gnu_java_net_protocol_http_Credentials, password) = r2;
	_JC_LINE_NUMBER(69);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getPassword()
//

static _jc_linenum _jc_gnu_java_net_protocol_http_Credentials$linenum_table$getPassword$32d96361835935c6[];

static const unsigned char _jc_gnu_java_net_protocol_http_Credentials$param_ptypes$getPassword$32d96361835935c6[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$getPassword$32d96361835935c6 = {
	.name=			"getPassword",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_gnu_java_net_protocol_http_Credentials$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_gnu_java_net_protocol_http_Credentials$param_ptypes$getPassword$32d96361835935c6,
	.signature_hash=	_JC_JLONG(0x32d96361835935c6),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_protocol_http_Credentials$method$getPassword$32d96361835935c6,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_net_protocol_http_Credentials$vtable, gnu_java_net_protocol_http_Credentials.getPassword$32d96361835935c6) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_net_protocol_http_Credentials$linenum_table$getPassword$32d96361835935c6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_protocol_http_Credentials, getPassword$32d96361835935c6);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_gnu_java_net_protocol_http_Credentials$method$getPassword$32d96361835935c6(_jc_env *const env, _jc_gnu_java_net_protocol_http_Credentials$object *this)
{
	struct _jc_gnu_java_net_protocol_http_Credentials$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(84);				// 0
	r1 = _JC_REF_FIELD(env, r0, gnu_java_net_protocol_http_Credentials, password);
	return r1;
}

//
// public java.lang.String getUsername()
//

static _jc_linenum _jc_gnu_java_net_protocol_http_Credentials$linenum_table$getUsername$3aabb4fed0b6ee73[];

static const unsigned char _jc_gnu_java_net_protocol_http_Credentials$param_ptypes$getUsername$3aabb4fed0b6ee73[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_java_net_protocol_http_Credentials$method_info$getUsername$3aabb4fed0b6ee73 = {
	.name=			"getUsername",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_gnu_java_net_protocol_http_Credentials$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_gnu_java_net_protocol_http_Credentials$param_ptypes$getUsername$3aabb4fed0b6ee73,
	.signature_hash=	_JC_JLONG(0x3aabb4fed0b6ee73),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_java_net_protocol_http_Credentials$method$getUsername$3aabb4fed0b6ee73,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_java_net_protocol_http_Credentials$vtable, gnu_java_net_protocol_http_Credentials.getUsername$3aabb4fed0b6ee73) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_java_net_protocol_http_Credentials$linenum_table$getUsername$3aabb4fed0b6ee73
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_java_net_protocol_http_Credentials, getUsername$3aabb4fed0b6ee73);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_gnu_java_net_protocol_http_Credentials$method$getUsername$3aabb4fed0b6ee73(_jc_env *const env, _jc_gnu_java_net_protocol_http_Credentials$object *this)
{
	struct _jc_gnu_java_net_protocol_http_Credentials$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(76);				// 0
	r1 = _JC_REF_FIELD(env, r0, gnu_java_net_protocol_http_Credentials, username);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_java_net_protocol_http_Credentials$methods[] = {
	&_jc_gnu_java_net_protocol_http_Credentials$method_info$_init$a34354cd9552963f,
	&_jc_gnu_java_net_protocol_http_Credentials$method_info$getPassword$32d96361835935c6,
	&_jc_gnu_java_net_protocol_http_Credentials$method_info$getUsername$3aabb4fed0b6ee73
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_bucket_12[] = {
	&_jc_gnu_java_net_protocol_http_Credentials$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[12]=	_jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_bucket_12,
	[101]=	_jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_java_net_protocol_http_Credentials$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_java_net_protocol_http_Credentials$vtype _jc_gnu_java_net_protocol_http_Credentials$type = {
    .type= {
	.name=			"gnu/java/net/protocol/http/Credentials",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x4e57e7668ee9620c),
		.source_file=		"Credentials.java",
		.instance_size=		sizeof(_jc_gnu_java_net_protocol_http_Credentials$refs) + sizeof(_jc_gnu_java_net_protocol_http_Credentials$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_gnu_java_net_protocol_http_Credentials$fields) / sizeof(*_jc_gnu_java_net_protocol_http_Credentials$fields),
		.fields=		_jc_gnu_java_net_protocol_http_Credentials$fields,
		.num_methods=		sizeof(_jc_gnu_java_net_protocol_http_Credentials$methods) / sizeof(*_jc_gnu_java_net_protocol_http_Credentials$methods),
		.methods=		_jc_gnu_java_net_protocol_http_Credentials$methods,
		.instanceof_hash_table=	_jc_gnu_java_net_protocol_http_Credentials$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_java_net_protocol_http_Credentials$class_depends) / sizeof(*_jc_gnu_java_net_protocol_http_Credentials$class_depends),
		.class_depends=		_jc_gnu_java_net_protocol_http_Credentials$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_java_net_protocol_http_Credentials= {
	    .getPassword$32d96361835935c6=
		&_jc_gnu_java_net_protocol_http_Credentials$method$getPassword$32d96361835935c6,
	    .getUsername$3aabb4fed0b6ee73=
		&_jc_gnu_java_net_protocol_http_Credentials$method$getUsername$3aabb4fed0b6ee73,
	},
    }
};
